Crate thifl_minigrep

Crate thifl_minigrep 

#Minigrep

minigrep is a a mini project with the goal of reproducting the behaviour of the grep command

Structs

Config

Functions

run
search
Search for query in the lines of contents. Returns a vector of str containing the lines.
search_case_insensitive